==> zio-aws-kafka_2.13-5.17.116.1-sources.jar: zio/aws/kafka/model/BrokerNodeGroupInfo.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.{__stringMin5Max32, __string}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class BrokerNodeGroupInfo(
    brokerAZDistribution: Option[zio.aws.kafka.model.BrokerAZDistribution] =
      None,
    clientSubnets: Iterable[__string],
    instanceType: __stringMin5Max32,
    securityGroups: Option[Iterable[__string]] = None,
    storageInfo: Option[zio.aws.kafka.model.StorageInfo] = None,
    connectivityInfo: Option[zio.aws.kafka.model.ConnectivityInfo] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.BrokerNodeGroupInfo = {
    import BrokerNodeGroupInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.BrokerNodeGroupInfo
      .builder()
      .optionallyWith(brokerAZDistribution.map(value => value.unwrap))(
        _.brokerAZDistribution
      )
      .clientSubnets(clientSubnets.map { item =>
        __string.unwrap(item): java.lang.String
      }.asJavaCollection)
      .instanceType(__stringMin5Max32.unwrap(instanceType): java.lang.String)
      .optionallyWith(
        securityGroups.map(value =>
          value.map { item =>
            __string.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.securityGroups)
      .optionallyWith(storageInfo.map(value => value.buildAwsValue()))(
        _.storageInfo
      )
      .optionallyWith(connectivityInfo.map(value => value.buildAwsValue()))(
        _.connectivityInfo
      )
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.BrokerNodeGroupInfo.ReadOnly =
    zio.aws.kafka.model.BrokerNodeGroupInfo.wrap(buildAwsValue())
}
object BrokerNodeGroupInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.BrokerNodeGroupInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.BrokerNodeGroupInfo =
      zio.aws.kafka.model.BrokerNodeGroupInfo(
        brokerAZDistribution.map(value => value),
        clientSubnets,
        instanceType,
        securityGroups.map(value => value),
        storageInfo.map(value => value.asEditable),
        connectivityInfo.map(value => value.asEditable)
      )
    def brokerAZDistribution: Option[zio.aws.kafka.model.BrokerAZDistribution]
    def clientSubnets: List[__string]
    def instanceType: __stringMin5Max32
    def securityGroups: Option[List[__string]]
    def storageInfo: Option[zio.aws.kafka.model.StorageInfo.ReadOnly]
    def connectivityInfo: Option[zio.aws.kafka.model.ConnectivityInfo.ReadOnly]
    def getBrokerAZDistribution
        : ZIO[Any, AwsError, zio.aws.kafka.model.BrokerAZDistribution] =
      AwsError.unwrapOptionField("brokerAZDistribution", brokerAZDistribution)
    def getClientSubnets: ZIO[Any, Nothing, List[__string]] =
      ZIO.succeed(clientSubnets)
    def getInstanceType: ZIO[Any, Nothing, __stringMin5Max32] =
      ZIO.succeed(instanceType)
    def getSecurityGroups: ZIO[Any, AwsError, List[__string]] =
      AwsError.unwrapOptionField("securityGroups", securityGroups)
    def getStorageInfo
        : ZIO[Any, AwsError, zio.aws.kafka.model.StorageInfo.ReadOnly] =
      AwsError.unwrapOptionField("storageInfo", storageInfo)
    def getConnectivityInfo
        : ZIO[Any, AwsError, zio.aws.kafka.model.ConnectivityInfo.ReadOnly] =
      AwsError.unwrapOptionField("connectivityInfo", connectivityInfo)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.BrokerNodeGroupInfo
  ) extends zio.aws.kafka.model.BrokerNodeGroupInfo.ReadOnly {
    override val brokerAZDistribution
        : Option[zio.aws.kafka.model.BrokerAZDistribution] = scala
      .Option(impl.brokerAZDistribution())
      .map(value => zio.aws.kafka.model.BrokerAZDistribution.wrap(value))
    override val clientSubnets: List[__string] = impl
      .clientSubnets()
      .asScala
      .map { item =>
        zio.aws.kafka.model.primitives.__string(item)
      }
      .toList
    override val instanceType: __stringMin5Max32 =
      zio.aws.kafka.model.primitives.__stringMin5Max32(impl.instanceType())
    override val securityGroups: Option[List[__string]] = scala
      .Option(impl.securityGroups())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.kafka.model.primitives.__string(item)
        }.toList
      )
    override val storageInfo: Option[zio.aws.kafka.model.StorageInfo.ReadOnly] =
      scala
        .Option(impl.storageInfo())
        .map(value => zio.aws.kafka.model.StorageInfo.wrap(value))
    override val connectivityInfo
        : Option[zio.aws.kafka.model.ConnectivityInfo.ReadOnly] = scala
      .Option(impl.connectivityInfo())
      .map(value => zio.aws.kafka.model.ConnectivityInfo.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.BrokerNodeGroupInfo
  ): zio.aws.kafka.model.BrokerNodeGroupInfo.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kafka_2.13-5.17.158.3-sources.jar: zio/aws/kafka/model/BrokerNodeGroupInfo.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.{__stringMin5Max32, __string}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class BrokerNodeGroupInfo(
    brokerAZDistribution: Option[zio.aws.kafka.model.BrokerAZDistribution] =
      None,
    clientSubnets: Iterable[__string],
    instanceType: __stringMin5Max32,
    securityGroups: Option[Iterable[__string]] = None,
    storageInfo: Option[zio.aws.kafka.model.StorageInfo] = None,
    connectivityInfo: Option[zio.aws.kafka.model.ConnectivityInfo] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.BrokerNodeGroupInfo = {
    import BrokerNodeGroupInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.BrokerNodeGroupInfo
      .builder()
      .optionallyWith(brokerAZDistribution.map(value => value.unwrap))(
        _.brokerAZDistribution
      )
      .clientSubnets(clientSubnets.map { item =>
        item: java.lang.String
      }.asJavaCollection)
      .instanceType(instanceType: java.lang.String)
      .optionallyWith(
        securityGroups.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.securityGroups)
      .optionallyWith(storageInfo.map(value => value.buildAwsValue()))(
        _.storageInfo
      )
      .optionallyWith(connectivityInfo.map(value => value.buildAwsValue()))(
        _.connectivityInfo
      )
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.BrokerNodeGroupInfo.ReadOnly =
    zio.aws.kafka.model.BrokerNodeGroupInfo.wrap(buildAwsValue())
}
object BrokerNodeGroupInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.BrokerNodeGroupInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.BrokerNodeGroupInfo =
      zio.aws.kafka.model.BrokerNodeGroupInfo(
        brokerAZDistribution.map(value => value),
        clientSubnets,
        instanceType,
        securityGroups.map(value => value),
        storageInfo.map(value => value.asEditable),
        connectivityInfo.map(value => value.asEditable)
      )
    def brokerAZDistribution: Option[zio.aws.kafka.model.BrokerAZDistribution]
    def clientSubnets: List[__string]
    def instanceType: __stringMin5Max32
    def securityGroups: Option[List[__string]]
    def storageInfo: Option[zio.aws.kafka.model.StorageInfo.ReadOnly]
    def connectivityInfo: Option[zio.aws.kafka.model.ConnectivityInfo.ReadOnly]
    def getBrokerAZDistribution
        : ZIO[Any, AwsError, zio.aws.kafka.model.BrokerAZDistribution] =
      AwsError.unwrapOptionField("brokerAZDistribution", brokerAZDistribution)
    def getClientSubnets: ZIO[Any, Nothing, List[__string]] =
      ZIO.succeed(clientSubnets)
    def getInstanceType: ZIO[Any, Nothing, __stringMin5Max32] =
      ZIO.succeed(instanceType)
    def getSecurityGroups: ZIO[Any, AwsError, List[__string]] =
      AwsError.unwrapOptionField("securityGroups", securityGroups)
    def getStorageInfo
        : ZIO[Any, AwsError, zio.aws.kafka.model.StorageInfo.ReadOnly] =
      AwsError.unwrapOptionField("storageInfo", storageInfo)
    def getConnectivityInfo
        : ZIO[Any, AwsError, zio.aws.kafka.model.ConnectivityInfo.ReadOnly] =
      AwsError.unwrapOptionField("connectivityInfo", connectivityInfo)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.BrokerNodeGroupInfo
  ) extends zio.aws.kafka.model.BrokerNodeGroupInfo.ReadOnly {
    override val brokerAZDistribution
        : Option[zio.aws.kafka.model.BrokerAZDistribution] = scala
      .Option(impl.brokerAZDistribution())
      .map(value => zio.aws.kafka.model.BrokerAZDistribution.wrap(value))
    override val clientSubnets: List[__string] = impl
      .clientSubnets()
      .asScala
      .map { item =>
        item: __string
      }
      .toList
    override val instanceType: __stringMin5Max32 =
      impl.instanceType(): __stringMin5Max32
    override val securityGroups: Option[List[__string]] = scala
      .Option(impl.securityGroups())
      .map(value =>
        value.asScala.map { item =>
          item: __string
        }.toList
      )
    override val storageInfo: Option[zio.aws.kafka.model.StorageInfo.ReadOnly] =
      scala
        .Option(impl.storageInfo())
        .map(value => zio.aws.kafka.model.StorageInfo.wrap(value))
    override val connectivityInfo
        : Option[zio.aws.kafka.model.ConnectivityInfo.ReadOnly] = scala
      .Option(impl.connectivityInfo())
      .map(value => zio.aws.kafka.model.ConnectivityInfo.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.BrokerNodeGroupInfo
  ): zio.aws.kafka.model.BrokerNodeGroupInfo.ReadOnly = new Wrapper(impl)
}
